@@ -32,14 +32,19 @@ from arrow.decorators import custom_exception, dict_output
     help="Set this if you don't want Apollo to reload genome sequences (no change in genome sequence)",
     is_flag=True
 )
+@click.option(
+    "--suppress_output",
+    help="Suppress output of all organisms (true / false) (default false)",
+    is_flag=True
+)
 @pass_context
 @custom_exception
 @dict_output
-def cli(ctx, organism_id, common_name, directory, blatdb="", species="", genus="", public=False, no_reload_sequences=False):
+def cli(ctx, organism_id, common_name, directory, blatdb="", species="", genus="", public=False, no_reload_sequences=False, suppress_output=False):
     """Update an organism
 
 Output:
 
     a dictionary with information about the updated organism
     """
-    return ctx.gi.organisms.update_organism(organism_id, common_name, directory, blatdb=blatdb, species=species, genus=genus, public=public, no_reload_sequences=no_reload_sequences)
+    return ctx.gi.organisms.update_organism(organism_id, common_name, directory, blatdb=blatdb, species=species, genus=genus, public=public, no_reload_sequences=no_reload_sequences, suppress_output=suppress_output)
